@@ -501,7 +501,9 @@ class JustpyServer:
             debug(bool): if True switch debugging on
         """
         if host is None:
-            host = socket.getfqdn()
+            host = socket.getfqdn() 
+            if host=="1.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.ip6.arpa":
+                host="localhost"
             # host="127.0.0.1"
         self.host = host
         self.port = port
